==> xfmail_1.5.1.orig.tar.gz: xfmail-1.5.1/src/mail/connection.h <==
/* $Id: connection.h,v 1.3 2001/07/10 03:22:57 fesnel Exp $ */
/*******************************************************************************
 *   This program is part of a library used by the Archimedes email client     * 
 *                                                                             *
 *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
 *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
 *               (C) 1998-2001 by the Archimedes Project                       *
 *                   http://sourceforge.net/projects/archimedes                *
 *                                                                             *
 *             --------------------------------------------                    *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
 *   it under the terms of the GNU Library General Public License as published *
 *   by the Free Software Foundation; either version 2 of the License, or      *
 *   (at your option) any later version.                                       *
 *                                                                             *
 *   This program is distributed in the hope that it will be useful,           *
 *   but WITHOUT ANY WARRANTY, without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *   GNU Library General Public License for more details.                      *
 *                                                                             *
 *   You should have received a copy of the GNU Library General Public License *
 *   along with this program; if not, write to the Free Software               *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307, USA.  *
 *                                                                             *
 ******************************************************************************/


#ifndef _CONNECTION_H_
#define _CONNECTION_H_

#include <fmail.h>
#include <config.h>
#include <umail.h>
#include <string>

#define CONNECTION_BUFFER 128

class connection {

public:

    connection(int psock, string phost);

    ~connection();

    void disconnect();

    connection * get();

    string getHost();

    int getSock();

    char * getBuf();

    friend bool operator == (const connection & lhs, const connection & rhs);

private:
    int sock;           /* socket file descriptor */
    char buffer[CONNECTION_BUFFER];    /* socket buffer      */
    string host;    /* host name (IP addr)    */
};
#endif

==> xfmail_1.5.5.orig.tar.gz: xfmail-1.5.5/src/mail/connection.h <==
/* $Id: connection.h,v 1.12 2004/01/02 03:54:01 fesnel Exp $ */
/*******************************************************************************
 *   This program is part of a library used by the Archimedes email client     * 
 *                                                                             *
 *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
 *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
 *               (C) 1998-2004 by the Archimedes Project                       *
 *                   http://sourceforge.net/projects/archimedes                *
 *                                                                             *
 *             --------------------------------------------                    *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
 *   it under the terms of the GNU Library General Public License as published *
 *   by the Free Software Foundation; either version 2 of the License, or      *
 *   (at your option) any later version.                                       *
 *                                                                             *
 *   This program is distributed in the hope that it will be useful,           *
 *   but WITHOUT ANY WARRANTY, without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *   GNU Library General Public License for more details.                      *
 *                                                                             *
 *   You should have received a copy of the GNU Library General Public License *
 *   along with this program; if not, write to the Free Software               *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307, USA.  *
 *                                                                             *
 ******************************************************************************/

#if !defined _CONNECTION_H_
#define _CONNECTION_H_

#include <string>

#include <umail.h>

#define CONNECTION_BUFFER 128

class connection {

public:

	connection(int psock, string phost);

	virtual ~connection();

	virtual void disconnect();
	virtual bool connect();

	connection * get();

	string getHost();

	int getSock();

	char * getBuf();

	friend bool operator == (const connection & lhs, const connection & rhs);

private:
	int sock;           /* socket file descriptor */
	char buffer[CONNECTION_BUFFER];    /* socket buffer      */
	string host;    /* host name (IP addr)    */
};

#endif // _CONNECTION_H_
